@@ -2,8 +2,10 @@
 
 #include "oidc-agent/oidcp/passwords/agent_prompt.h"
 #include "utils/agentLogger.h"
+#include "utils/json.h"
 #include "utils/memory.h"
 #include "utils/oidc_error.h"
+#include "utils/prompting/getprompt.h"
 #include "utils/string/stringUtils.h"
 
 char* askpass_getPasswordForUpdate(const char* shortname) {
@@ -15,10 +17,9 @@ char* askpass_getPasswordForUpdate(const char* shortname) {
       DEBUG,
       "Prompting user for encryption password for updating account config '%s'",
       shortname);
-  const char* const fmt =
-      "oidc-agent needs to update the account config for '%s'.\nPlease enter "
-      "the encryption password for '%s':";
-  char* msg = oidc_sprintf(fmt, shortname, shortname);
+  cJSON* data = generateJSONObject("shortname", cJSON_String, shortname, NULL);
+  char*  msg  = getprompt(PROMPTTEMPLATE(UPDATE_ACCOUNT), data);
+  secFreeJson(data);
   char* ret = agent_promptPassword(msg, "Encryption password", NULL);
   secFree(msg);
   if (ret == NULL) {
@@ -36,16 +37,10 @@ char* askpass_getPasswordForAutoload(const char* shortname,
   agent_log(DEBUG,
             "Prompting user for encryption password for autoload config '%s'",
             shortname);
-  const char* const fmt =
-      "An application %srequests an access token for '%s'.\nThis configuration "
-      "is currently not loaded.\nTo load '%s' into oidc-agent please enter "
-      "the encryption password for '%s':";
-  char* application_str = strValid(application_hint)
-                              ? oidc_sprintf("(%s) ", application_hint)
-                              : NULL;
-  char* msg =
-      oidc_sprintf(fmt, application_str ?: "", shortname, shortname, shortname);
-  secFree(application_str);
+  cJSON* data = generateJSONObject("shortname", cJSON_String, shortname, NULL);
+  data        = jsonAddStringValue(data, "application-hint", application_hint);
+  char* msg   = getprompt(PROMPTTEMPLATE(UNLOCK_ACCOUNT), data);
+  secFreeJson(data);
   char* ret = agent_promptPassword(msg, "Encryption password", NULL);
   secFree(msg);
   if (ret == NULL) {
@@ -66,17 +61,11 @@ char* askpass_getPasswordForAutoloadWithIssuer(const char* issuer,
       "Prompting user for encryption password for autoload config '%s' for "
       "issuer '%s'",
       shortname, issuer);
-  const char* const fmt =
-      "An application %srequests an access token for '%s',\nbut there's "
-      "currently no account configuration loaded for this provider.\nThe "
-      "default account configuration for this provider is '%s'.\nTo load '%s' "
-      "into oidc-agent please enter the encryption password for '%s':";
-  char* application_str = strValid(application_hint)
-                              ? oidc_sprintf("(%s) ", application_hint)
-                              : NULL;
-  char* msg = oidc_sprintf(fmt, application_str ?: "", issuer, shortname,
-                           shortname, shortname);
-  secFree(application_str);
+  cJSON* data = generateJSONObject("shortname", cJSON_String, shortname,
+                                   "issuer", cJSON_String, issuer, NULL);
+  data        = jsonAddStringValue(data, "application-hint", application_hint);
+  char* msg   = getprompt(PROMPTTEMPLATE(UNLOCK_ACCOUNT_ISSUER), data);
+  secFreeJson(data);
   char* ret = agent_promptPassword(msg, "Encryption password", NULL);
   secFree(msg);
   if (ret == NULL) {
@@ -85,6 +74,25 @@ char* askpass_getPasswordForAutoloadWithIssuer(const char* issuer,
   return ret;
 }
 
+oidc_error_t _askpass_getConfirmation(const char* issuer, const char* shortname,
+                                      const char* application_hint,
+                                      const char* token_type) {
+  cJSON* data =
+      generateJSONObject("shortname", cJSON_String, shortname, "token-type",
+                         cJSON_String, token_type, NULL);
+  data = jsonAddStringValue(data, "issuer", issuer);
+  data = jsonAddStringValue(data, "application-hint", application_hint);
+  if (strcaseequal(token_type, "id")) {
+    data = jsonAddBoolValue(data, "id", cJSON_True);
+  }
+  char* msg = getprompt(PROMPTTEMPLATE(CONFIRM), data);
+  secFreeJson(data);
+  oidc_errno =
+      agent_promptConsentDefaultYes(msg) ? OIDC_SUCCESS : OIDC_EFORBIDDEN;
+  secFree(msg);
+  return oidc_errno;
+}
+
 oidc_error_t askpass_getConfirmation(const char* shortname,
                                      const char* application_hint) {
   if (shortname == NULL) {
@@ -93,18 +101,7 @@ oidc_error_t askpass_getConfirmation(const char* shortname,
   }
   agent_log(DEBUG, "Prompting user for confirmation of using config '%s'",
             shortname);
-  const char* const fmt =
-      "An application %srequests an access token for '%s'.\n"
-      "Do you want to allow this usage?";
-  char* application_str = strValid(application_hint)
-                              ? oidc_sprintf("(%s) ", application_hint)
-                              : NULL;
-  char* msg             = oidc_sprintf(fmt, application_str ?: "", shortname);
-  secFree(application_str);
-  oidc_errno =
-      agent_promptConsentDefaultYes(msg) ? OIDC_SUCCESS : OIDC_EFORBIDDEN;
-  secFree(msg);
-  return oidc_errno;
+  return _askpass_getConfirmation(NULL, shortname, application_hint, "access");
 }
 
 oidc_error_t askpass_getConfirmationWithIssuer(const char* issuer,
@@ -118,18 +115,8 @@ oidc_error_t askpass_getConfirmationWithIssuer(const char* issuer,
       DEBUG,
       "Prompting user for confirmation of using config '%s' for issuer '%s'",
       shortname, issuer);
-  const char* const fmt =
-      "An application %srequests an access token for '%s'.\n"
-      "Do you want to allow the usage of '%s'?";
-  char* application_str = strValid(application_hint)
-                              ? oidc_sprintf("(%s) ", application_hint)
-                              : NULL;
-  char* msg = oidc_sprintf(fmt, application_str ?: "", issuer, shortname);
-  secFree(application_str);
-  oidc_errno =
-      agent_promptConsentDefaultYes(msg) ? OIDC_SUCCESS : OIDC_EFORBIDDEN;
-  secFree(msg);
-  return oidc_errno;
+  return _askpass_getConfirmation(issuer, shortname, application_hint,
+                                  "access");
 }
 
 oidc_error_t askpass_getIdTokenConfirmation(const char* shortname,
@@ -140,19 +127,7 @@ oidc_error_t askpass_getIdTokenConfirmation(const char* shortname,
   }
   agent_log(DEBUG, "Prompting user for id-token confirmation for config '%s'",
             shortname);
-  const char* const fmt =
-      "An application %srequests an id token for '%s'.\n"
-      "id tokens should not be passed to other applications as authorization.\n"
-      "Do you want to allow this usage?";
-  char* application_str = strValid(application_hint)
-                              ? oidc_sprintf("(%s) ", application_hint)
-                              : NULL;
-  char* msg             = oidc_sprintf(fmt, application_str ?: "", shortname);
-  secFree(application_str);
-  oidc_errno =
-      agent_promptConsentDefaultYes(msg) ? OIDC_SUCCESS : OIDC_EFORBIDDEN;
-  secFree(msg);
-  return oidc_errno;
+  return _askpass_getConfirmation(NULL, shortname, application_hint, "id");
 }
 
 oidc_error_t askpass_getIdTokenConfirmationWithIssuer(
@@ -161,20 +136,7 @@ oidc_error_t askpass_getIdTokenConfirmationWithIssuer(
             "Prompting user for id-token confirmation for "
             "issuer '%s'",
             issuer);
-  const char* const fmt =
-      "An application %srequests an id token for '%s'.\n"
-      "id tokens should not be passed to other applications as authorization.\n"
-      "Do you want to allow the usage of '%s'?";
-  char* application_str = strValid(application_hint)
-                              ? oidc_sprintf("(%s) ", application_hint)
-                              : NULL;
-  char* msg =
-      oidc_sprintf(fmt, application_str ?: "", issuer, shortname ?: issuer);
-  secFree(application_str);
-  oidc_errno =
-      agent_promptConsentDefaultYes(msg) ? OIDC_SUCCESS : OIDC_EFORBIDDEN;
-  secFree(msg);
-  return oidc_errno;
+  return _askpass_getConfirmation(issuer, shortname, application_hint, "id");
 }
 
 char* askpass_getMytokenConfirmation(const char* base64_html) {
