@@ -5,12 +5,14 @@
 #include "defines/agent_values.h"
 #include "defines/settings.h"
 #include "utils/commonFeatures.h"
+#include "utils/config/configUtils.h"
+#include "utils/config/gen_config.h"
 #include "utils/guiChecker.h"
 #include "utils/listUtils.h"
 #include "utils/memory.h"
 #include "utils/portUtils.h"
 #include "utils/printer.h"
-#include "utils/prompt_mode.h"
+#include "utils/prompting/prompt_mode.h"
 #include "utils/string/stringUtils.h"
 #include "utils/uriUtils.h"
 
@@ -140,7 +142,7 @@ static struct argp_option options[] = {
 
     {0, 0, 0, 0, "Generating a new account configuration - Advanced:", 3},
     {"at", OPT_TOKEN, "ACCESS_TOKEN", 0,
-     "Use ACCESS_TOKEN for authorization for authorization at the registration "
+     "Use ACCESS_TOKEN for authorization at the registration "
      "endpoint.",
      3},
     {"access-token", OPT_TOKEN, "ACCESS_TOKEN", OPTION_ALIAS, NULL, 3},
@@ -279,7 +281,7 @@ void initArguments(struct arguments* arguments) {
   arguments->pw_env                        = NULL;
   arguments->pw_cmd                        = NULL;
   arguments->pw_file                       = NULL;
-  arguments->pw_gpg                        = NULL;
+  arguments->pw_gpg                        = getGenConfig()->default_gpg_key;
   arguments->file                          = NULL;
 
   arguments->client_id       = NULL;
@@ -290,38 +292,42 @@ void initArguments(struct arguments* arguments) {
   arguments->dynRegToken     = NULL;
   arguments->cert_path       = NULL;
   arguments->refresh_token   = NULL;
-  arguments->cnid            = NULL;
+  arguments->cnid            = getGenConfig()->cnid;
   arguments->audience        = NULL;
   arguments->op_username     = NULL;
   arguments->op_password     = NULL;
   arguments->mytoken_profile = NULL;
 
-  arguments->mytoken_issuer.str   = NULL;
+  arguments->mytoken_issuer.str   = getGenConfig()->default_mytoken_server;
   arguments->mytoken_issuer.useIt = 0;
 
   arguments->flows         = NULL;
+  arguments->flows_set     = 1;
   arguments->redirect_uris = NULL;
 
-  arguments->debug           = 0;
+  arguments->debug           = getGenConfig()->debug;
   arguments->manual          = 0;
   arguments->verbose         = 0;
   arguments->delete          = 0;
   arguments->listAccounts    = 0;
-  arguments->noUrlCall       = 0;
+  arguments->noUrlCall       = !getGenConfig()->autoopenurl;
   arguments->usePublicClient = 0;
   arguments->noWebserver     = 0;
   arguments->reauthenticate  = 0;
   arguments->noScheme        = 0;
-  arguments->confirm_no      = 0;
-  arguments->confirm_yes     = 0;
-  arguments->confirm_default = 0;
-  arguments->only_at         = 0;
-  arguments->noSave          = 0;
-  arguments->oauth           = 0;
+  arguments->confirm_no =
+      getGenConfig()->answer_confirm_prompts_mode == CONFIRM_PROMPT_MODE_NO;
+  arguments->confirm_yes =
+      getGenConfig()->answer_confirm_prompts_mode == CONFIRM_PROMPT_MODE_YES;
+  arguments->confirm_default = getGenConfig()->answer_confirm_prompts_mode ==
+                               CONFIRM_PROMPT_MODE_DEFAULT;
+  arguments->only_at = 0;
+  arguments->noSave  = 0;
+  arguments->oauth   = 0;
 
-  arguments->pw_prompt_mode = 0;
+  arguments->pw_prompt_mode = getGenConfig()->pw_prompt_mode;
   set_pw_prompt_mode(arguments->pw_prompt_mode);
-  arguments->prompt_mode = PROMPT_MODE_CLI;
+  arguments->prompt_mode = getGenConfig()->prompt_mode;
   set_prompt_mode(arguments->prompt_mode);
 }
 
@@ -422,27 +428,23 @@ static error_t parse_opt(int key, char* arg, struct argp_state* state) {
       arguments->rename = arg;
       break;
     case OPT_PW_PROMPT_MODE:
-      if (strequal(arg, "cli")) {
-        arguments->pw_prompt_mode = PROMPT_MODE_CLI;
-      } else if (strequal(arg, "gui")) {
-        arguments->pw_prompt_mode = PROMPT_MODE_GUI;
-        common_assertOidcPrompt();
-      } else {
+      arguments->pw_prompt_mode = parse_prompt_mode(arg);
+      if (arguments->pw_prompt_mode == PROMPT_MODE_INVALID) {
         return ARGP_ERR_UNKNOWN;
       }
+      if (arguments->pw_prompt_mode == PROMPT_MODE_GUI) {
+        common_assertOidcPrompt();
+      }
       set_pw_prompt_mode(arguments->pw_prompt_mode);
       break;
     case OPT_PROMPT_MODE:
-      if (strequal(arg, "cli")) {
-        arguments->prompt_mode = PROMPT_MODE_CLI;
-      } else if (strequal(arg, "gui")) {
-        arguments->prompt_mode = PROMPT_MODE_GUI;
-        common_assertOidcPrompt();
-      } else if (strequal(arg, "none")) {
-        arguments->prompt_mode = 0;
-      } else {
+      arguments->prompt_mode = parse_prompt_mode(arg);
+      if (arguments->prompt_mode == PROMPT_MODE_INVALID) {
         return ARGP_ERR_UNKNOWN;
       }
+      if (arguments->prompt_mode == PROMPT_MODE_GUI) {
+        common_assertOidcPrompt();
+      }
       set_prompt_mode(arguments->prompt_mode);
       break;
     case OPT_TOKEN: arguments->dynRegToken = arg; break;
@@ -459,10 +461,14 @@ static error_t parse_opt(int key, char* arg, struct argp_state* state) {
     }
     case OPT_MYTOKENURL:
       arguments->mytoken_issuer.useIt = 1;
-      arguments->mytoken_issuer.str   = arg;
-      arguments->client_id            = "mytoken";
-      arguments->client_secret        = "mytoken";
-      arguments->manual               = 1;
+      if (arg != NULL) {
+        arguments->mytoken_issuer.str = arg;
+      }
+      arguments->mytoken_profile =
+          arguments->mytoken_profile ?: getGenConfig()->default_mytoken_profile;
+      arguments->client_id     = "mytoken";
+      arguments->client_secret = "mytoken";
+      arguments->manual        = 1;
       break;
     case OPT_MYTOKENPROFILE:
       arguments->mytoken_profile = arg;
@@ -544,6 +550,7 @@ static error_t parse_opt(int key, char* arg, struct argp_state* state) {
         _setMTFlow(arguments);
       }
       if (arguments->flows == NULL) {
+        arguments->flows_set    = 0;
         arguments->flows        = list_new();
         arguments->flows->match = (matchFunction)strequal;
         if (GUIAvailable()) {
