@@ -3,7 +3,8 @@
 #include "utils/listUtils.h"
 #include "utils/logger.h"
 #include "utils/memory.h"
-#include "utils/prompt.h"
+#include "utils/prompting/getprompt.h"
+#include "utils/prompting/prompt.h"
 #include "utils/string/stringUtils.h"
 
 char* _gen_prompt(char* label, const char* init, int passPrompt, int optional) {
@@ -13,7 +14,7 @@ char* _gen_prompt(char* label, const char* init, int passPrompt, int optional) {
     prompter = promptPassword;
   }
   do {
-    char* text = oidc_sprintf("Please enter %s:", label);
+    char* text = get_general_prompt(label);
     input      = prompter(text, label, init, CLI_PROMPT_NOT_VERBOSE);
     secFree(text);
     if (strValid(input)) {
@@ -31,7 +32,7 @@ char* _gen_promptMultipleSpaceSeparated(char* label, const char* init_str,
   list_t* init  = delimitedStringToList(init_str, ' ');
   list_t* input = NULL;
   do {
-    char* text = oidc_sprintf("Please enter %s:", label);
+    char* text = get_general_prompt(label);
     input      = promptMultiple(text, label, init, CLI_PROMPT_NOT_VERBOSE);
     secFree(text);
     if (listValid(input)) {
