@@ -28,9 +28,6 @@ int readCertPath(struct oidc_account*    account,
   if (prompt_mode() == 0 && strValid(account_getCertPath(account))) {
     return 1;
   }
-  if (account_getCertPath(account) == NULL) {
-    account_setOSDefaultCertPath(account);
-  }
   return 0;
 }
 
