@@ -2,6 +2,7 @@
 #define OIDCGEN_PROMPTANDSET_H
 
 #include "account/account.h"
+#include "name.h"
 #include "oidc-gen/oidc-gen_options.h"
 
 int  readClientId(struct oidc_account*, const struct arguments*);
@@ -15,7 +16,7 @@ void needClientSecret(struct oidc_account*, const struct arguments*);
 void askOrNeedClientSecret(struct oidc_account*, const struct arguments*, int);
 
 void _suggestTheseIssuers(list_t* issuers, struct oidc_account* account,
-                          int optional);
+                          const struct arguments* arguments, int optional);
 int  readIssuer(struct oidc_account*, const struct arguments*);
 void askIssuer(struct oidc_account*, const struct arguments*);
 void needIssuer(struct oidc_account*, const struct arguments*);
@@ -56,11 +57,6 @@ void askCertPath(struct oidc_account*, const struct arguments*);
 void needCertPath(struct oidc_account*, const struct arguments*);
 void askOrNeedCertPath(struct oidc_account*, const struct arguments*, int);
 
-int  readName(struct oidc_account*, const struct arguments*);
-void askName(struct oidc_account*, const struct arguments*);
-void needName(struct oidc_account*, const struct arguments*);
-void askOrNeedName(struct oidc_account*, const struct arguments*, int);
-
 void _askOrNeedScope(char* supportedScope, struct oidc_account* account,
                      const struct arguments* arguments, int optional);
 int  readScope(struct oidc_account*, const struct arguments*);
