@@ -7,11 +7,13 @@
 oidc_error_t promptEncryptAndWriteToFile(
     const char* text, const char* filepath, const char* hint,
     const char* suggestedPassword, const char* pw_cmd, const char* pw_file,
-    const char* pw_env, const char* gpg_key);
+    const char* pw_env, const char* gpg_key,
+    oidc_error_t (*callback)(const char*, const char*, const char*));
 oidc_error_t promptEncryptAndWriteToOidcFile(
     const char* text, const char* filename, const char* hint,
     const char* suggestedPassword, const char* pw_cmd, const char* pw_file,
-    const char* pw_env, const char* gpg_key);
+    const char* pw_env, const char* gpg_key,
+    oidc_error_t (*callback)(const char*, const char*, const char*));
 struct resultWithEncryptionPassword getDecryptedFileAndPasswordFor(
     const char* filepath, const char* pw_cmd, const char* pw_file,
     const char* pw_env);
